@@ -144,7 +144,7 @@ usage() {
     "-b, --bin-dir" "Override the bin installation directory [default: ${BIN_DIR}]" \
     "-a, --arch" "Override the architecture identified by the installer [default: ${ARCH}]" \
     "-B, --base-url" "Override the base URL used for downloading releases [default: ${BASE_URL}]" \
-    "-h, --help" "Dispays this help message"
+    "-h, --help" "Display this help message"
 }
 
 elevate_priv() {
@@ -297,7 +297,7 @@ print_install() {
     # we don't want these '~' expanding
     config_file="~/.${s}rc"
     config_cmd="eval \"\$(starship init ${s})\""
- 
+
     case ${s} in
       ion )
         # shellcheck disable=SC2088
@@ -336,22 +336,19 @@ print_install() {
         ;;
       nushell )
         # shellcheck disable=SC2088
-        config_file="your nu config file."
-        config_cmd="startup = [
-          \"mkdir ~/.cache/starship\",
-          \"starship init nu | save ~/.cache/starship/init.nu\",
-          \"source ~/.cache/starship/init.nu\"
-        ]
-        prompt = \"starship_prompt\""
+        config_file="${BOLD}your nu config file${NO_COLOR} (find it by running ${BOLD}\$nu.config-path${NO_COLOR} in Nushell)"
+        config_cmd="mkdir ~/.cache/starship
+        starship init nu | save ~/.cache/starship/init.nu
+        source ~/.cache/starship/init.nu"
         warning="${warning} This will change in the future.
-  Only nu version v0.33 or higher is supported.
-  You can check the location of this your config file by running config path in nu"
+  Only Nushell v0.61 or higher is supported.
+  Add the following to the end of ${BOLD}your Nushell env file${NO_COLOR} (find it by running ${BOLD}\$nu.env-path${NO_COLOR} in Nushell): \"mkdir ~/.cache/starship; starship init nu | save ~/.cache/starship/init.nu\""
         ;;
     esac
-    printf "  %s\n  %s\n  Add the following to the end of %s:\n\n\t%s\n\n" \
+    printf "  %s\n  %s\n  And add the following to the end of %s:\n\n\t%s\n\n" \
       "${BOLD}${UNDERLINE}${s}${NO_COLOR}" \
       "${warning}" \
-      "${BOLD}${config_file}${NO_COLOR}" \
+      "${config_file}" \
       "${config_cmd}"
   done
 
